/**
 * OW2 geolocalization
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: jonas-team@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: RecordView.java 5338 2010-02-16 09:29:44Z loris $
 * --------------------------------------------------------------------------
 */
package org.ow2.util.geolocation.web.back;

import java.io.IOException;
import java.io.PrintWriter;
import javax.ejb.EJB;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.ow2.util.geolocation.business.GeoLocatorInterface;
import org.ow2.util.geolocation.business.entity.GeolocalisedProduct;

/**
 * The management interface of the app.
 * 
 * @author mancelin
 */
public class RecordView extends HttpServlet {

    /**
     * A null string.
     */
    private static final String NULL = "";
    /**
     * The geolocalization EJB.
     */
    @EJB
    private GeoLocatorInterface clientSess;

    /**
     * Processes requests for both HTTP <code>GET</code> and <code>POST</code> methods.
     * @param request servlet request
     * @param response servlet response
     * @throws ServletException if a servlet-specific error occurs
     * @throws IOException if an I/O error occurs
     */
    protected void processRequest(final HttpServletRequest request, final HttpServletResponse response)
            throws ServletException, IOException {
        response.setContentType("text/html;charset=UTF-8");
        PrintWriter out = response.getWriter();
        String id = request.getParameter("id");
        try {
            out.println("<html>");
            out.println("<head>");
            out.println("<title>OW2 Products Users record view</title>");
            out.println("<link href=\"http://wiki.jonas.ow2.org/xwiki/bin/skin/XWiki/MySkin/style.css\""
                    + "rel=\"stylesheet\" type=\"text/css\"  />");
            out.println("<link href=\"http://wiki.jonas.ow2.org/xwiki/bin/skin/XWiki/MySkin/style.css\""
                    + " rel=\"stylesheet\" type=\"text/css\" title=\"default\" />");
            out.println("<link href=\"http://wiki.jonas.ow2.org/xwiki/bin/skin/XWiki/MySkin/style.css\""
                    + " rel=\"alternate stylesheet\" type=\"text/css\"  title=\"Alternate StyleSheet 1\" />");
            out.println("</head>");
            out.println("<body>");
            out.println("<div id=\"content\">");
            out.println("<a href=\"http://www.ow2.org/\">");
            out.println("<img src=\"/OW2ProductsService/header.jpg\"" + " alt=\"JOnAS header\" />");
            out.println("</a>");
            out.println("<div id=\"ow2logo\">");
            out.println("<a href=\"http://www.ow2.org\">");
            out.println("<img src=\"http://wiki.jonas.ow2.org/xwiki/bin/download/XWiki/MySkin/ow2_small.png\""
                    + " alt=\"OW2\" title=\"OW2\" />");
            out.println("</a>");
            out.println("</div>");
            out.println("<div id=\"communitylinks\">");
            out.println("<ul>");
            out.println("<li><a title=\"Users Map\" href=\"/OW2ProductsMap/\">Users Map</a></li>");
            out.println("<li>|</li>");
            out.println("<li><a title=\"Admin\" href=\"/OW2ProductsService/mgmt.html\">Admin</a></li>");
            out.println("<li>|</li>");
            out.println("<li><a href=\"/OW2ProductsService/mgmt/showAll\">Manage records</a></li>");
            out.println("<li>|</li>");
            out.println("<li><a href=\"/OW2ProductsService/mgmt/manage\">Manage products</a></li>");
            out.println("<li>|</li>");
            out.println("<li><a href=\"/OW2ProductsService/logout\">Logout</a></li>");
            out.println("</ul>");
            out.println("</div>");
            out.println("<h1 align=\"center\">Record view</h1>");
            out.println("<div align=\"center\">");
            out.println("<br/>");
            out.println("<br/>");
            if (id != null) {
                GeolocalisedProduct p = clientSess.findAProduct(id);
                out.println("<TABLE BORDER=\"1\" ALIGN=\"middle\" CELLPADDING=5>");
                out.println("<TR BGCOLOR=\"#FFFFB0\">");
                out.println("<TH> Attribute name </TH>");
                out.println("<TH> Value </TH>");
                out.println("</TR><TR>");
                out.println("<TD align=\"center\"> ID </TD>");
                out.println("<TD align=\"center\"> " + p.getId() + " </TD>");
                out.println("</TR><TR>");
                out.println("<TD align=\"center\"> Date </TD>");
                out.println("<TD align=\"center\"> " + p.getRecordDate() + " </TD>");
                out.println("</TR><TR>");
                out.println("<TD align=\"center\"> IP </TD>");
                out.println("<TD align=\"center\"> " + p.getIpAddress() + " </TD>");
                out.println("</TR><TR>");
                out.println("<TD align=\"center\"> Product name </TD>");
                out.println("<TD align=\"center\"> " + p.getProductName().getName() + " </TD>");
                out.println("</TR><TR>");
                out.println("<TD align=\"center\"> Product version </TD>");
                out.println("<TD align=\"center\"> " + p.getProductVersion().getVersion() + " </TD>");
                out.println("</TR><TR>");
                out.println("<TD align=\"center\"> Email </TD>");
                out.println("<TD align=\"center\"> " + p.getEmail() + " </TD>");
                out.println("</TR><TR>");
                out.println("<TD align=\"center\"> City </TD>");
                out.println("<TD align=\"center\"> " + p.getCity() + " </TD>");
                out.println("</TR><TR>");
                out.println("<TD align=\"center\"> Country code </TD>");
                out.println("<TD align=\"center\"> " + p.getCountryCode() + " </TD>");
                out.println("</TR><TR>");
                out.println("<TD align=\"center\"> Country </TD>");
                out.println("<TD align=\"center\"> " + p.getCountryName() + " </TD>");
                out.println("</TR><TR>");
                out.println("<TD align=\"center\"> Postal code </TD>");
                out.println("<TD align=\"center\"> " + p.getPostalCode() + " </TD>");
                out.println("</TR><TR>");
                out.println("<TD align=\"center\"> Region </TD>");
                out.println("<TD align=\"center\"> " + p.getRegion() + " </TD>");
                out.println("</TR><TR>");
                out.println("<TD align=\"center\"> Region name </TD>");
                out.println("<TD align=\"center\"> " + p.getRegionName() + " </TD>");
                out.println("</TR><TR>");
                out.println("<TD align=\"center\"> Timezone </TD>");
                out.println("<TD align=\"center\"> " + p.getTimezone() + " </TD>");
                out.println("</TR><TR>");
                out.println("<TD align=\"center\"> Area code </TD>");
                out.println("<TD align=\"center\"> " + p.getAreaCode() + " </TD>");
                out.println("</TR><TR>");
                out.println("<TD align=\"center\"> DMA code </TD>");
                out.println("<TD align=\"center\"> " + p.getDmaCode() + " </TD>");
                out.println("</TR><TR>");
                out.println("<TD align=\"center\"> Metro code </TD>");
                out.println("<TD align=\"center\"> " + p.getMetroCode() + " </TD>");
                out.println("</TR><TR>");
                out.println("<TD align=\"center\"> Latitude </TD>");
                out.println("<TD align=\"center\"> " + p.getLatitude() + " </TD>");
                out.println("</TR><TR>");
                out.println("<TD align=\"center\"> Longitude </TD>");
                out.println("<TD align=\"center\"> " + p.getLongitude() + " </TD>");
                out.println("</TR>");
                if (p.getAttributes() != null) {
                    outputTechnicalAttributes(out, p);
                }            
                out.println("</TABLE>");
            }            
            out.println("<br/>");
            out.println("<br/>");
            out.println("</div>");
            out.println("</body>");
            out.println("</html>");
        } finally {
            out.close();
        }
    }
    /**
     * Display technical attributes of a geolocalised.
     * @param out the printwriter of the servlet.
     * @param p the displayed product.
     */
    private void outputTechnicalAttributes(final PrintWriter out, final GeolocalisedProduct p) {
        out.println("<TR>");
        out.println("<TD align=\"center\"> OS </TD>");
        out.println("<TD align=\"center\"> " + p.getAttributes().getOsName() + " </TD>");
        out.println("</TR><TR>");
        out.println("<TD align=\"center\"> Version </TD>");
        out.println("<TD align=\"center\"> " + p.getAttributes().getOsVersion() + " </TD>");
        out.println("</TR><TR>");
        out.println("<TD align=\"center\"> Architecture </TD>");
        out.println("<TD align=\"center\"> " + p.getAttributes().getOsArch() + " </TD>");
        out.println("</TR><TR>");
        out.println("<TD align=\"center\"> JRE vendor </TD>");
        out.println("<TD align=\"center\"> " + p.getAttributes().getJreVendor() + " </TD>");
        out.println("</TR><TR>");
        out.println("<TD align=\"center\"> JRE version </TD>");
        out.println("<TD align=\"center\"> " + p.getAttributes().getJreVersion() + " </TD>");
        out.println("</TR><TR>");
        out.println("<TD align=\"center\"> JVM Name </TD>");
        out.println("<TD align=\"center\"> " + p.getAttributes().getJvmName() + " </TD>");
        out.println("</TR><TR>");
        out.println("<TD align=\"center\"> JVM Vendor </TD>");
        out.println("<TD align=\"center\"> " + p.getAttributes().getJvmVendor() + " </TD>");
        out.println("</TR><TR>");
        out.println("<TD align=\"center\"> JVM Version </TD>");
        out.println("<TD align=\"center\"> " + p.getAttributes().getJvmVersion() + " </TD>");
        out.println("</TR><TR>");
        out.println("<TD align=\"center\"> Processor(s) </TD>");
        out.println("<TD align=\"center\"> " + p.getAttributes().getNumProc() + " </TD>");
        out.println("</TR>");
    }

    /** 
     * Handles the HTTP <code>GET</code> method.
     * @param request servlet request
     * @param response servlet response
     * @throws ServletException if a servlet-specific error occurs
     * @throws IOException if an I/O error occurs
     */
    @Override
    protected void doGet(final HttpServletRequest request, final HttpServletResponse response)
            throws ServletException, IOException {
        processRequest(request, response);
    }

    /** 
     * Handles the HTTP <code>POST</code> method.
     * @param request servlet request
     * @param response servlet response
     * @throws ServletException if a servlet-specific error occurs
     * @throws IOException if an I/O error occurs
     */
    @Override
    protected void doPost(final HttpServletRequest request, final HttpServletResponse response)
            throws ServletException, IOException {
        processRequest(request, response);
    }

    /** 
     * Returns a short description of the servlet.
     * @return a String containing servlet description
     */
    @Override
    public String getServletInfo() {
        return "Short description";
    }
}
